//****************************************************
//***** AITENDO 128x64 OLED controlling  *************
//*************************** By Minarai Shokunin ****
//*************************** 2013/09/21          ****
//****************************************************

#include "p24FJ64GA002.h"
#include "oled.h"

// ************ prototypes ***************************
void OLED_init(void);
void Copy2OLED(void);
void WriteByte(int,int);
void delay_some(int);

// ************ Values ***************************
unsigned char VirtualScreen[8][128];

// ************ Initialization ***************************
void OLED_init()
{
	int i,j;
	
	// ********** Init Interface Signals & reset*************

	OLED_CS 	= H;			//  NO SELECT
	OLED_CLK	= H;			//  CLK = High
	OLED_A0		= H;			//  A0 = High
	OLED_DAT	= H;			//  DATA = High

	OLED_RST = L;				//  RESET ON
	delay_some(10);		//  Wait a bit
	OLED_RST = H;			//  RESET OFF
	delay_some(100);		//  Wait a bit

	// *********** Init OLED Registers *************************

     WriteByte(_CMD,0xAE);     //Set Display Off
     WriteByte(_CMD,0xd5);     //display divide ratio/osc. freq. mode
     WriteByte(_CMD,0x80);     //
     WriteByte(_CMD,0xA8);     //multiplex ration mode:63
     WriteByte(_CMD,0x3F);
     WriteByte(_CMD,0xD3);     //Set Display Offset
     WriteByte(_CMD,0x00);  
     WriteByte(_CMD,0x40);     //Set Display Start Line
     WriteByte(_CMD,0x8D);     //Set Display Offset
     //WriteByte(_CMD,0x10);
     WriteByte(_CMD,0x14);
     WriteByte(_CMD,0xA1);     //Segment Remap
     WriteByte(_CMD,0xC8);     //Sst COM Output Scan Direction
      //Write_command(0xC8);
     WriteByte(_CMD,0xDA);     //common pads hardware: alternative
     WriteByte(_CMD,0x12);
     WriteByte(_CMD,0x81);     //contrast control 
      //Write_command(0x9F);     // 
     WriteByte(_CMD,0x66);
     WriteByte(_CMD,0xD9);	    //set pre-charge period
      //Write_command(0x22);	    //set period 1:1;period 2:15
     WriteByte(_CMD,0xF1);
     WriteByte(_CMD,0xDB);     //VCOM deselect level mode
     WriteByte(_CMD,0x40);	    //set Vvcomh=0.83*Vcc
     WriteByte(_CMD,0xA4);     //Set Entire Display On/Off
     WriteByte(_CMD,0xA6);     //Set Normal Display
     WriteByte(_CMD,0xAF);     //Set Display On

	// ********** Init Screen Data *******

	for (i=0;i<8;i++) {
		for (j=0;j<128;j++) {
			VirtualScreen[i][j] = 0;
		}
	}

	Copy2OLED();

}

//********** Copy data to OLED *************
void Copy2OLED(void) {
	int i,j;

	for (i=0;i<8;i++) {

    	WriteByte(_CMD,0xb0+i);
    	WriteByte(_CMD,0x10);
    	WriteByte(_CMD,0x00);

		for (j=0;j<128;j++) {
			WriteByte(_DAT,VirtualScreen[i][j]);
		}
	}
}

//********** Write cmd/Data to OLED *************

void WriteByte(int add,int data) {
	int i,dt;

	dt = data;

	OLED_A0 = add;				// Address set
	OLED_CS = L;					// CS = L
	delay_some(2);
	for (i=0;i<8;i++) {
		OLED_CLK	= L;			// CLK 
		//delay_some(1);
		OLED_DAT = (dt >> 7) & 1;
		//delay_some(1);
		OLED_CLK	= H;			// CLK 
		dt <<=1;
		//delay_some(1);
	}
	//delay_some(2);
	OLED_CS = H;					// CS = H

}
//********** Simple wait loop *************
void delay_some(int t)
{
	int i,j;
	for (i=0;i